<!--
 *  Copyright 2013-2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
 *
 *  Licensed under the Creative Commons Attribution-Share Alike 3.0 Unported licence
 *  available at http://creativecommons.org/licenses/by-sa/3.0/
-->
<!DOCTYPE html>
<html>
<head>
<title>Script API Documentation Plugin: Overview</title>
<link rel="stylesheet" href="bootstrap.css" />
<link rel="stylesheet" href="bootstrap-apiview.css" />
</head>
<body>

<div style="margin: 10pt" id="rocs-content-text">
<h1>{{ i18nScriptEngineApi }}</h1>

<h2>{{ i18nDocument }}</h2>
<ul>
{% for component in kernelElements %}
    <li>
        <a href="http://virtual/{{ component.id }}">{{ component.title }}</a>
    </li>
{% endfor %}
</ul>

<h2>{{ i18nEngineComponents }}</h2>
<ul>
{% for component in kernelModules %}
    <li>
        <a href="http://virtual/{{ component.id }}">{{ component.title }}</a>
    </li>
{% endfor %}
</ul>

</div>
</body>
</html>
